@@ -19,6 +19,7 @@ use Text::Amuse::Compile::Webfonts;
 use Text::Amuse::Compile::File;
 use Text::Amuse::Compile::Merged;
 use Text::Amuse::Compile::MuseHeader;
+use Text::Amuse::Compile::FileName;
 
 use Cwd;
 use Fcntl qw/:flock/;
@@ -31,11 +32,11 @@ Text::Amuse::Compile - Compiler for Text::Amuse
 
 =head1 VERSION
 
-Version 0.46
+Version 0.50
 
 =cut
 
-our $VERSION = '0.46';
+our $VERSION = '0.50';
 
 =head1 SYNOPSIS
 
@@ -509,7 +510,7 @@ sub _compile_virtual_file {
     my $suffix = delete($virtual{suffix}) || '.muse';
     my $name =   delete($virtual{name})   || 'virtual';
     $self->logger->("Working on virtual file in " . getcwd(). "\n");
-    my @filelist = map { $_ . $suffix } @$files;
+    my @filelist = map { Text::Amuse::Compile::FileName->new($_) } @$files;
     my $doc = Text::Amuse::Compile::Merged->new(files => \@filelist, %virtual);
     my $muse = Text::Amuse::Compile::File->new(
                                                name => $name,
@@ -529,26 +530,26 @@ sub _compile_virtual_file {
 
 sub _compile_file {
     my ($self, $file) = @_;
-    die "$file is not a file" unless $file && -f $file;
-    # parse the filename and chdir there.
-    my ($name, $path, $suffix) = fileparse($file, qr{\.muse});
+    my $fileobj = Text::Amuse::Compile::FileName->new($file);
+    die "$file is not a file" unless $fileobj && -f $fileobj->full_path;
 
-    if ($path) {
+    if (my $path = $fileobj->path) {
         chdir $path or die "Cannot chdir into $path from " . getcwd() . "\n" ;
     };
 
-    my $filename = $name . $suffix;
+    my $filename = $fileobj->filename;
     $self->logger->("Working on $filename file in " . getcwd(). "\n");
 
     my %args = (
-                name => $name,
-                suffix => $suffix,
+                name => $fileobj->name,
+                suffix => $fileobj->suffix,
                 templates => $self->templates,
                 options => { $self->extra },
                 logger => $self->logger,
                 standalone => $self->standalone,
                 webfonts => $self->webfonts,
                 luatex => $self->luatex,
+                fileobj => $fileobj,
                );
 
     my $muse = Text::Amuse::Compile::File->new(%args);
@@ -638,16 +639,14 @@ file.
 
 sub _check_file_basename {
     my ($self, $file) = @_;
-    die "Bad usage" unless $file;
-    die "$file is not a file" unless -f $file;
-    my ($name, $path, $suffix) = fileparse($file, qr{\.muse});
-    die "Bad usage, not a muse file" unless $suffix;
-    return File::Spec->catfile($path, $name);
+    my $fileobj = Text::Amuse::Compile::FileName->new($file);
+    return File::Spec->catfile($fileobj->path, $fileobj->name);
 }
 
 sub parse_muse_header {
     my ($self, $file) = @_;
-    return Text::Amuse::Compile::MuseHeader->new(muse_fast_scan_header($file));
+    my $path = Text::Amuse::Compile::FileName->new($file)->full_path;
+    return Text::Amuse::Compile::MuseHeader->new(muse_fast_scan_header($path));
 }
 
 
