@@ -59,6 +59,10 @@ If it's a virtual file which doesn't exit on the disk (a merged one)
 
 =item templates
 
+=item fileobj
+
+An optional L<Text::Amuse::Compile::FileName> object (for partials)
+
 =item standalone
 
 When set to true, the tex output will obey bcor and twoside/oneside.
@@ -119,6 +123,7 @@ has virtual => (is => 'ro', isa => Bool, default => sub { 0 });
 has standalone => (is => 'ro', isa => Bool, default => sub { 0 });
 has tt => (is => 'ro', isa => Object, default => sub { Template::Tiny->new });
 has logger => (is => 'ro', isa => Maybe[CodeRef]);
+has fileobj => (is => 'ro', isa => Maybe[Object]);
 has webfonts => (is => 'ro', isa => Maybe[Object]);
 has document => (is => 'lazy', isa => Object);
 has options => (is => 'ro', isa => HashRef, default => sub { +{} });
@@ -151,7 +156,14 @@ sub _build_wants_slides {
 
 sub _build_document {
     my $self = shift;
-    return Text::Amuse->new(file => $self->muse_file);
+    my %args;
+    if (my $fileobj = $self->fileobj) {
+        %args = $fileobj->text_amuse_constructor;
+    }
+    else {
+        %args = (file => $self->muse_file);
+    }
+    return Text::Amuse->new(%args);
 }
 
 sub _build_tex_options {
@@ -599,22 +611,10 @@ sub epub {
 
     my @pieces = $text->as_splat_html;
     my @toc = $text->raw_html_toc;
-    my $missing = scalar(@pieces) - scalar(@toc);
-    # this shouldn't happen
-
-    # print Dumper(\@toc);
-
-    if ($missing > 1 or $missing < 0) {
-        # $self->log_info(Dumper(\@pieces), Dumper(\@toc));
+    # fixed in 0.51
+    if (my $missing = scalar(@pieces) - scalar(@toc)) {
         $self->log_fatal("This shouldn't happen: missing pieces: $missing");
     }
-    elsif ($missing == 1) {
-        unshift @toc, {
-                       index => 0,
-                       level => 1,
-                       string => "start body",
-                      };
-    }
     my $epub = EBook::EPUB::Lite->new;
 
     # embedded CSS
@@ -630,13 +630,13 @@ sub epub {
     if ($text->header_defined->{author}) {
         my $author = $header->{author};
         $epub->add_author($self->_clean_html($author));
-        $titlepage .= "<h2>$author</h2>\n";
+        $titlepage .= "<h2>$author</h2>\n" if $text->wants_preamble;
     }
 
     if ($text->header_defined->{title}) {
         my $t = $header->{title};
         $epub->add_title($self->_clean_html($t));
-        $titlepage .= "<h1>$t</h1>\n";
+        $titlepage .= "<h1>$t</h1>\n" if $text->wants_preamble;
     }
     else {
         $epub->add_title('Untitled');
@@ -644,13 +644,13 @@ sub epub {
 
     if ($text->header_defined->{subtitle}) {
         my $st = $header->{subtitle};
-        $titlepage .= "<h2>$st</h2>\n"
+        $titlepage .= "<h2>$st</h2>\n" if $text->wants_preamble;
     }
     if ($text->header_defined->{date}) {
         if ($header->{date} =~ m/([0-9]{4})/) {
             $epub->add_date($1);
         }
-        $titlepage .= "<h3>$header->{date}</h3>"
+        $titlepage .= "<h3>$header->{date}</h3>" if $text->wants_preamble;
     }
 
     $epub->add_language($text->language_code);
@@ -658,13 +658,13 @@ sub epub {
     if ($text->header_defined->{source}) {
         my $source = $header->{source};
         $epub->add_source($self->_clean_html($source));
-        $titlepage .= "<p>$source</p>";
+        $titlepage .= "<p>$source</p>" if $text->wants_postamble;
     }
 
     if ($text->header_defined->{notes}) {
         my $notes = $header->{notes};
         $epub->add_description($self->_clean_html($notes));
-        $titlepage .= "<p>$notes</p>";
+        $titlepage .= "<p>$notes</p>" if $text->wants_postamble;
     }
 
     # create the front page
